Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(2140)

Unified Diff: content/public/child/child_thread.h

Issue 2398783002: Rename a bunch of Mojo Application stuff to reference Services. (Closed)
Patch Set: . Created 4 years, 2 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « content/public/browser/content_browser_client.cc ('k') | content/public/common/BUILD.gn » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: content/public/child/child_thread.h
diff --git a/content/public/child/child_thread.h b/content/public/child/child_thread.h
index 32611ac15ec3b32937a5c6f4d3bbb5a019aee1c6..9d2fa88dd4502e7f82ca7414da2affcb80bf65e9 100644
--- a/content/public/child/child_thread.h
+++ b/content/public/child/child_thread.h
@@ -27,7 +27,7 @@ class InterfaceRegistry;
namespace content {
-class MojoShellConnection;
+class ServiceManagerConnection;
// An abstract base class that contains logic shared between most child
// processes of the embedder.
@@ -67,9 +67,9 @@ class CONTENT_EXPORT ChildThread : public IPC::Sender {
// actions in chrome/tools/extract_actions.py.
virtual void RecordComputedAction(const std::string& action) = 0;
// Returns the MojoShellConnection for the thread (from which a
// shell::Connector can be obtained).
- virtual MojoShellConnection* GetMojoShellConnection() = 0;
+ virtual ServiceManagerConnection* GetServiceManagerConnection() = 0;
// Returns the InterfaceRegistry that this process uses to expose interfaces
// to the browser.
« no previous file with comments | « content/public/browser/content_browser_client.cc ('k') | content/public/common/BUILD.gn » ('j') | no next file with comments »
@@ -67,9 +67,9 @@ class CONTENT_EXPORT ChildThread : public IPC::Sender {
// actions in chrome/tools/extract_actions.py.
virtual void RecordComputedAction(const std::string& action) = 0;
- // Returns the MojoShellConnection for the thread (from which a
+ // Returns the ServiceManagerConnection for the thread (from which a
// shell::Connector can be obtained).

Powered by Google App Engine
This is Rietveld 408576698